@@ -80,12 +80,18 @@ FAILEDOPERATION_GETPRIVILEGEERROR = 'FailedOperation.GetPrivilegeError'
 # 查询失败。
 FAILEDOPERATION_INSTANCEQUERYERROR = 'FailedOperation.InstanceQueryError'
 
+# 实例任务冲突错误。
+FAILEDOPERATION_INSTANCETASKCONFLICTERROR = 'FailedOperation.InstanceTaskConflictError'
+
 # json序列化失败。
 FAILEDOPERATION_JSONMARSHALERROR = 'FailedOperation.JsonMarshalError'
 
 # json反序列化失败。
 FAILEDOPERATION_JSONUNMARSHALERROR = 'FailedOperation.JsonUnmarshalError'
 
+# 返回数据量过大，请缩减数据查询范围
+FAILEDOPERATION_LOGCONTENTOVERLIMIT = 'FailedOperation.LogContentOverLimit'
+
 # 检查到改动前后策略一致，无改动点。
 FAILEDOPERATION_NOTCHANGESTRATEGY = 'FailedOperation.NotChangeStrategy'
 
@@ -95,6 +101,9 @@ FAILEDOPERATION_NOTDELAYRO = 'FailedOperation.NotDelayRo'
 # 实例正在执行其他操作，请稍后重试。
 FAILEDOPERATION_OPERATIONINCONFLICTERR = 'FailedOperation.OperationInConflictErr'
 
+# 实例正在执行其他操作，请稍后重试。
+FAILEDOPERATION_OPERATIONINCONFLICTERROR = 'FailedOperation.OperationInConflictError'
+
 # 执行的权限修改操作非法。您可以参照产品文档，了解当前实例支持哪些权限修改操作，如有疑问，请您咨询客服进行处理。
 FAILEDOPERATION_PRIVILEGEDATAILLEGAL = 'FailedOperation.PrivilegeDataIllegal'
 
@@ -116,6 +125,9 @@ FAILEDOPERATION_REPEATCREATEPROXYERROR = 'FailedOperation.RepeatCreateProxyError
 # 后台请求服务异常，请您联系客服解决。
 FAILEDOPERATION_RESPONSEVALUEERROR = 'FailedOperation.ResponseValueError'
 
+# 查询日志结果集超出限制，请缩小查询范围。
+FAILEDOPERATION_RESULTSETOVERLIMIT = 'FailedOperation.ResultSetOverLimit'
+
 # 操作发起失败，请稍后重试。如果操作持续不成功，请您联系客服进行处理。
 FAILEDOPERATION_STARTFLOWERROR = 'FailedOperation.StartFlowError'
 
@@ -134,6 +146,9 @@ FAILEDOPERATION_TYPEINCONFLICT = 'FailedOperation.TypeInConflict'
 # 该IP已被占用。
 FAILEDOPERATION_VPCIPINUSEERROR = 'FailedOperation.VpcIpInUseError'
 
+# 无效IP
+FAILEDOPERATION_VPCIPINVALIDERROR = 'FailedOperation.VpcIpInvalidError'
+
 # 子网中不存在该IP
 FAILEDOPERATION_VPCIPNOTINSUBNETERROR = 'FailedOperation.VpcIpNotInSubnetError'
 
@@ -185,7 +200,7 @@ INTERNALERROR_DBERROR = 'InternalError.DBError'
 # 数据库操作失败。
 INTERNALERROR_DBOPERATIONERROR = 'InternalError.DBOperationError'
 
-# 数据库记录不存在。
+# 数据库实例不存在。
 INTERNALERROR_DBRECORDNOTEXISTERROR = 'InternalError.DBRecordNotExistError'
 
 # 数据库内部错误。
@@ -212,6 +227,9 @@ INTERNALERROR_FTPERROR = 'InternalError.FtpError'
 # Http请求异常。
 INTERNALERROR_HTTPERROR = 'InternalError.HttpError'
 
+# 请求失败。
+INTERNALERROR_HTTPREQUESTERROR = 'InternalError.HttpRequestError'
+
 # 导入失败。
 INTERNALERROR_IMPORTERROR = 'InternalError.ImportError'
 
@@ -551,7 +569,7 @@ RESOURCENOTFOUND = 'ResourceNotFound'
 # 未找到数据库实例，请确认您的实例状态是否正常。
 RESOURCENOTFOUND_CDBINSTANCENOTFOUNDERROR = 'ResourceNotFound.CdbInstanceNotFoundError'
 
-# 高可用版实例不存在。
+# 该实例不存在。
 RESOURCENOTFOUND_INSTANCENOTFOUNDERROR = 'ResourceNotFound.InstanceNotFoundError'
 
 # 该实例不存在。
@@ -560,6 +578,9 @@ RESOURCENOTFOUND_INSTANCENOTFUNDERROR = 'ResourceNotFound.InstanceNotFundError'
 # 资源不可用。
 RESOURCEUNAVAILABLE = 'ResourceUnavailable'
 
+# 未授权操作。
+UNAUTHORIZEDOPERATION = 'UnauthorizedOperation'
+
 # 认证失败，没有足够权限。
 UNAUTHORIZEDOPERATION_NOTENOUGHPRIVILEGES = 'UnauthorizedOperation.NotEnoughPrivileges'
 
